import { ComponentType, FC } from 'react';
import { Converters, HTMLAttributes2ReactProps } from '../types';
export type HTML2ReactProps = {
    /** The HTML content to be converted to React components. */
    html: string;
    /** Custom tag components to replace HTML tags. If a component is not provided, the corresponding HTML tag will be used. */
    components?: Partial<Record<keyof JSX.IntrinsicElements, ComponentType<Record<string, any>> | keyof JSX.IntrinsicElements>> & Record<string, ComponentType<Record<string, any>> | keyof JSX.IntrinsicElements>;
    /** Map HTML attributes to corresponding React props. If the attribute is not specified, it will be passed as is. */
    attributes?: Partial<HTMLAttributes2ReactProps> & Record<string, string>;
    /** Converters for processing attribute values. If no converter is provided, the property will be of type string. */
    converters?: Converters;
    /**
     * Process text segments within the HTML content.
     * @param segment - The text segment to be processed.
     * @returns The processed text segment.
     */
    processTextSegment?(segment: string): string;
};
declare const HTML2React: FC<HTML2ReactProps>;
export default HTML2React;
