import React from 'react';
import identity from 'lodash.identity';

// src/HTML2React/index.tsx

// src/constants.ts
var NON_WHITESPACE_CHARACTER = /[^\s]/;
var HTML_SPECIAL_CHAR = /[\s>/]/;
var HTML_ATTRIBUTE_CHAR = /[=\s>/]/;
var VOID_TAGS = /* @__PURE__ */ new Set([
  "area",
  "base",
  "br",
  "col",
  "embed",
  "hr",
  "img",
  "input",
  "link",
  "meta",
  "param",
  "source",
  "track",
  "wbr"
]);
var HTML2React = ({
  html,
  components = {},
  attributes = {},
  converters = {},
  processTextSegment = identity
}) => {
  let start = 0;
  const tagsQueue = new Array(1);
  const childrenQueue = [[]];
  const search = (index, regexp) => {
    const next = html.substring(index).search(regexp);
    if (next < 0) {
      throw new Error("invalid html");
    }
    return index + next;
  };
  const indexOf = (item, index) => {
    index = html.indexOf(item, index);
    if (index < 0) {
      throw new Error("invalid html");
    }
    return index;
  };
  for (let index = html.indexOf("<"), char; index != -1; index = html.indexOf("<", index)) {
    const parentChildren = childrenQueue[childrenQueue.length - 1];
    if (start != index) {
      parentChildren.push(processTextSegment(html.substring(start, index)));
    }
    char = html[++index];
    if (char == "/") {
      start = ++index;
      index = indexOf(">", index);
      const tag = html.substring(start, index).trim();
      for (let j = tagsQueue.length; j--; ) {
        if (tagsQueue[j] == tag) {
          tagsQueue.length = j;
          childrenQueue.length = j;
          break;
        }
      }
    } else if (char != "!") {
      start = index;
      index = search(index, HTML_SPECIAL_CHAR);
      const tag = html.substring(start, index);
      const Component = components[tag] || tag;
      const props = {
        key: parentChildren.length
      };
      while (true) {
        index = search(index, NON_WHITESPACE_CHARACTER);
        char = html[index];
        if (char == "/" || char == ">") {
          break;
        }
        start = index;
        index = search(index, HTML_ATTRIBUTE_CHAR);
        char = html[index];
        const htmlKey = html.substring(start, index);
        const key = attributes[htmlKey] || htmlKey;
        let value;
        if (char != "=" && char != "/" && char != ">") {
          index = search(index + 1, NON_WHITESPACE_CHARACTER);
        }
        if (html[index] == "=") {
          index = search(index + 1, NON_WHITESPACE_CHARACTER);
          char = html[index];
          const isWrapped = char == "'" || char == '"';
          const next = isWrapped ? indexOf(char, ++index) : search(index, HTML_SPECIAL_CHAR);
          value = html.substring(index, next);
          index = next + isWrapped;
        } else {
          value = "true";
        }
        props[key] = key in converters ? converters[key](value) : value;
      }
      if (html[index] == "/") {
        index++;
      }
      if (tag != "script") {
        if (!VOID_TAGS.has(tag)) {
          childrenQueue.push(props.children = []);
          tagsQueue.push(tag);
        }
      } else {
        const str = html.substring(index + 1);
        const scriptClosingTag = /<\/\s*script\s*>/.exec(str);
        if (scriptClosingTag) {
          const indexOfNextScriptOpenTag = str.search(/<\s*script\s*>/);
          const indexOfScriptClosingTag = scriptClosingTag.index;
          if (indexOfNextScriptOpenTag == -1 || indexOfScriptClosingTag < indexOfNextScriptOpenTag) {
            const code = str.substring(0, indexOfScriptClosingTag);
            if (code) {
              props.dangerouslySetInnerHTML = { __html: code };
            }
            index += indexOfScriptClosingTag + scriptClosingTag[0].length;
          }
        }
      }
      parentChildren.push(/* @__PURE__ */ React.createElement(Component, { ...props }));
    } else {
      index = indexOf("-->", index + 1) + 2;
    }
    start = ++index;
  }
  if (start < html.length) {
    childrenQueue[childrenQueue.length - 1].push(
      processTextSegment(html.substring(start))
    );
  }
  return /* @__PURE__ */ React.createElement(React.Fragment, null, childrenQueue[0]);
};
var HTML2React_default = HTML2React;

export { HTML2React_default };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=chunk-2CTMCUAV.js.map